=encoding utf8

=head1

Locale::CLDR::Locales::Da::Any::Gl - Package for language Danish

=cut

package Locale::CLDR::Locales::Da::Any::Gl;
# This file auto generated from Data/common/main/da_GL.xml
#	on Mon 11 Apr  5:26:14 pm GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.34.1');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

extends('Locale::CLDR::Locales::Da::Any');
no Moo;

1;

# vim: tabstop=4
